@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.24.3-Tisler"
-#define _QGIS_VERSION "3.24.3-Tisler"
+#define VERSION "3.26.1-Buenos Aires"
+#define _QGIS_VERSION "3.26.1-Buenos Aires"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3243
+//#define VERSION_INT 3261
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 32403
-#define _QGIS_VERSION_INT 32403
-#define ABISYM(x) x ## 32403
+#define VERSION_INT 32601
+#define _QGIS_VERSION_INT 32601
+#define ABISYM(x) x ## 32601
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Tisler"
+#define RELEASE_NAME "Buenos Aires"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -31,7 +31,7 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr"
-#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.24.3"
+#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.26.1"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
@@ -51,9 +51,9 @@
 #define PYTHON_VERSION_MINOR "10"
 #define PYTHON_VERSION_PATCH "5"
 
-#define PROJ_VERSION_MAJOR 8
-#define PROJ_VERSION_MINOR 2
-#define PROJ_VERSION_PATCH 0
+#define PROJ_VERSION_MAJOR 9
+#define PROJ_VERSION_MINOR 0
+#define PROJ_VERSION_PATCH 1
 
 /* #undef USING_NMAKE */
 
@@ -98,6 +98,8 @@
 
 #define HAVE_EPT
 
+#define HAVE_COPC
+
 #define HAVE_PDAL_QGIS
 #define PDAL_VERSION "2.4.2"
 #define PDAL_VERSION_MAJOR_INT 2
